<?php
namespace Concrete\Package\TwitterPush;

use Concrete\Core\Package\Package;
use Concrete\Core\Page\Single as SinglePage;
use Concrete\Core\Support\Facade\Application;
use Concrete\Core\Support\Facade\Events;
use Concrete\Core\Entity\Attribute\Key\PageKey;
use Concrete\Core\Support\Facade\Log;
use TwitterPush\TwitterPush\Push;

class Controller extends Package {
	protected $pkgHandle = 'twitter_push';
	protected $appVersionRequired = '8.4.3';
	protected $pkgVersion = '0.94';

	public function getPackageDescription () {
		return t("Push a published page as a Tweet in your Twitter feed.");
	}

	public function getPackageName () {
		return t("Push as Tweet");
	}

	public function install () {
		$pkg = parent::install();
        $page = SinglePage::add('/dashboard/pages/push',$pkg);
        $page->updateCollectionName(t('Push to Twitter'));

        $service = $this->app->make('Concrete\Core\Attribute\Category\CategoryService');
        $categoryEntity = $service->getByHandle('collection');
        $category = $categoryEntity->getController();

        $key = $category->getByHandle('push_to_twitter');
        if (!is_object($key)) {
            $key = new PageKey();
            $key->setAttributeKeyHandle('push_to_twitter');
            $key->setAttributeKeyName('Push this Page to Twitter');
            $key = $category->add('boolean', $key, null, $pkg);
        }		
	}

    protected $pkgAutoloaderRegistries = [
        'src' => '\TwitterPush',
    ];

    public function on_start() {   
        require $this->getPackagePath() . '/vendor/autoload.php';
        Events::addListener('on_page_type_publish', [new Push(), 'pageAdd']);
    }
}
